@@ -704,7 +704,7 @@ class MockAirflowConnectionWithHostKey:
         self.login = "username"
         self.password = "password"
         self.extra = f'{{ "no_host_key_check": {no_host_key_check}, "host_key": {host_key} }}'
-        self.extra_dejson = {  # type: ignore
+        self.extra_dejson = {
             "no_host_key_check": no_host_key_check,
             "host_key": host_key,
             "key_file": "~/keys/my_key",
@@ -814,11 +814,9 @@ class TestSFTPHookAsync:
         )
 
         hook = SFTPHookAsync()
-        with pytest.raises(ValueError) as exc:
+        with pytest.raises(ValueError, match="Host key check was skipped, but `host_key` value was given"):
             await hook._get_conn()
 
-        assert str(exc.value) == "Host key check was skipped, but `host_key` value was given"
-
     @patch("paramiko.SSHClient.connect")
     @patch("asyncssh.import_private_key")
     @patch("asyncssh.connect", new_callable=AsyncMock)
@@ -854,7 +852,7 @@ class TestSFTPHookAsync:
             "username": "username",
             "password": "password",
             "client_keys": "~/keys/my_key",
-            "known_hosts": "~/.ssh/known_hosts",
+            "known_hosts": None,
             "passphrase": "mypassphrase",
         }
 
@@ -882,6 +880,7 @@ class TestSFTPHookAsync:
             "username": "username",
             "password": "password",
             "client_keys": ["test"],
+            "known_hosts": None,
             "passphrase": "mypassphrase",
         }
 
